@@ -1,13 +1,9 @@
 package main
 
-import (
-	"os"
-	"os/exec"
-)
+import "os/exec"
 
 func getCmdOutput(cmds ...string) ([]byte, error) {
 	command := exec.Command(cmds[0], cmds[1:]...)
-	command.Stderr = os.Stderr
 	output, err := command.Output()
 	if err != nil {
 		return nil, err
